@@ -1,7 +1,8 @@
 import dataclasses
-import logging
 import typing
 
+import logging
+
 
 @dataclasses.dataclass(
     frozen=True,
@@ -84,9 +85,9 @@ class WorkerConfig:
 
     def replace(
         self,
-        *args,
-        **kwargs,
-    ):
+        *args: typing.Any,
+        **kwargs: typing.Any,
+    ) -> 'WorkerConfig':
         return dataclasses.replace(
             self,
             *args,
